\name{logit1}
\alias{lik.logit1}
\alias{grad.logit1}
\alias{lik.beta.logit1}
\alias{grad.beta.logit1}
\alias{prof.logit1}
\alias{reml.logit1}
\title{Logistic regression with random intercepts. }
\description{Functions for log-likelihood computations.
}
\usage{lik.logit1(theta, X, y, ni, mat, type = "gl")
grad.logit1(theta, X, y, ni, mat, type = "gl")
lik.beta.logit1(beta, psi, X, y, ni, mat, type)
grad.beta.logit1(beta, psi, X, y, ni, mat, type)
prof.logit1(psi, X, y, ni, mat, beta.init, type = "gl", method="BFGS")
reml.logit1(psi, X, y, ni, mat,  beta.init, mle, type = "gl",method="BFGS")}
\arguments{
  \item{theta}{parameter value, formed by fixed effects and random effects standard deviation
\eqn{\psi}{psi} (in that order). A vector of dimension \eqn{p+1}{p+1}, where \eqn{p}{p} is the number of fixed effects.  }
  \item{beta}{parameter value for  fixed effects.  }
  \item{psi}{random effects standard deviation. }
  \item{X}{ a matrix of explanatory variables, of order \eqn{n \times p}{n x p}. }
  \item{y}{ a matrix of order  \eqn{n \times 2}{n x 2}. The first column contains the response variable, and the second column the binomial denominators. }
  \item{ni}{ cluster sizes, a vector of length equal to the nymber of clusters \eqn{m}{m}.  }
  \item{mat}{ object containing the information used for numerical integration. For Gauss-Legendre, is an object returned by calling the function \code{gauss.quad} of library \code{statmod}. For Monte Carlo integration is a matrix of order \eqn{m \times Q}{m x Q} of uniform randon draws. A suggested choice is to use Quasi-Monte Carlo draws.}
  \item{type}{method used for Monte Carlo integration, either \code{"gl"} for Gauss-Legendre integration or any other value for Monte Carlo integration.  The default is \code{"gl"}. }
\item{beta.init}{starting value for fixed effects to be used for  maximization of \code{lik.beta.logit1}.}
\item{mle}{numerical value of maximun likelihood estimate of fixed effects and \eqn{\psi}{psi}.}
\item{method}{method for \code{optim} call for  maximization of \code{lik.beta.logit1}. Default is \code{"BFGS"}.}
}
\details{ \code{lik.logit1} and \code{grad.logit1} return the log-likelihood and the gradient for the full parameter, while \code{lik.beta.logit1} and \code{grad.beta.logit1} return the same quantities when the random effect variance is taken as known. \code{prof.logit1} and \code{reml.logit1} return the profile and modified profile log-likelihoods for the variance component \eqn{\psi^2}{psi^2}.
The two functions 
\code{lik.logit1} and 
\code{grad.logit1} can be used for finding the maximum likelihood estimate for all the parameters, while \code{lik.beta.logit1} and 
\code{grad.beta.logit1} for finding the constrained estimate of fixed effects. The main functions are \code{prof.logit1} and 
\code{reml.logit1}, which can be directly used for inference on \eqn{\psi}{psi}. 
}
\value{
For  \code{lik.logit1},  \code{lik.beta.logit1},  \code{prof.logit1} and  \code{reml.logit1} a log-likelihood value. For  \code{grad.logit1} and 
\code{grad.beta.logit1}
a gradient value, for the whole parameter and fixed effects only respectively.
}
\references{ Bellio, R. and Brazzale, A. R. (2011). "Restricted Likelihood Inference for Generalized Linear Mixed Models". Statistics and Computing, 21, 173-183.  }
\author{Ruggero Bellio <ruggero.bellio@uniud.it>}

\examples{
## Multicenter data 
data(multicenter)
## Create some of the required data objects
X <- model.matrix(~I(trt==1), data=multicenter)
y <- cbind(multicenter$y, multicenter$den)
N <- tapply(rep(1,nrow(X)), multicenter$ID, sum)
## Laplace-based MLE  for finding a  preliminary estimate
obj.lap <- glmer(cbind(y,den-y) ~ I(trt==1) + (1|ID), family=binomial, data=multicenter)
init <- c(fixef(obj.lap), sqrt((VarCorr(obj.lap)$ID)[1]))
## Maximum likelihood estimation based on Gauss-Legendre integration
mat.gl <-  gauss.quad(50,"legendre")
mle <- optim(init, lik.logit1, grad.logit1, X=X, y=y, ni=N, mat=mat.gl, type="gl",
             method="BFGS", control=list(fnscale=-1))$par 
##  Obtain the profile and reml log-likelihood plot
x.values<- seq(0.7,4,l=30)
prof.values <- sapply(x.values, prof.logit1, X, y, ni=N, mat=mat.gl, type="gl",
                      beta.init=fixef(obj.lap))
reml.values <- sapply(x.values, reml.logit1, X, y, ni=N, mat=mat.gl, type="gl",
                      beta.init=fixef(obj.lap), mle=mle)
plot(x.values, prof.values-max(prof.values), type="l", xlab=expression(psi), 
     ylab="Loglikelihood")
lines(x.values, reml.values-max(reml.values), lty=2)
## The function QUnif of package "sfsmisc" provides Halton sequences for 
## Quasi-Monte Carlo integration
Q <- 2000
mat.halton <- matrix(rep(QUnif(1000, p=1),length(N)), length(N), 1000, byrow=TRUE) 
mle.halton <- optim(init, lik.logit1, grad.logit1, X=X, y=y, ni=N, mat=mat.halton, 
                    type="qmc", method="BFGS", control=list(fnscale=-1))$par 
x.values<- seq(0.7,4,l=30)
prof.values.halton <- sapply(x.values, prof.logit1, X, y, ni=N, mat=mat.halton, 
                             type="qmc", beta.init=fixef(obj.lap))
reml.values.halton <- sapply(x.values, reml.logit1, X, y, ni=N, mat=mat.halton, 
                             type="qmc", beta.init=fixef(obj.lap), mle=mle.halton)
lines(x.values, prof.values.halton-max(prof.values.halton), col="red")
lines(x.values, reml.values.halton-max(reml.values.halton), col="red", lty=2)
}
\keyword{regression }
