\name{logit2}
\alias{lik.logit2}
\alias{lik.beta.logit2}
\alias{grad.beta.logit2}
\alias{prof.logit2}
\alias{reml.logit2}
\title{ Logistic regression with random intercepts and slopes. }
\description{
 Functions for log-likelihood computations.
}
\usage{
lik.logit2(theta, X, Z, y, ni, mat, type = "gl")
lik.beta.logit2(beta, psi, X, Z, y, ni,  mat, type)
grad.beta.logit2(beta, psi, X, Z, y, ni,  mat, type)
prof.logit2(psi, X, Z, y, ni,  mat, beta.init, type = "gl", method="BFGS")
reml.logit2(psi, X, Z, y, ni, mat, beta.init, mle, type = "gl", method="BFGS")
}
\arguments{
  \item{theta}{parameter value, formed by fixed effects and 
\eqn{\psi}{psi} (in that order). A vector of dimension \eqn{p+3}{p+3}, where \eqn{p}{p} is the number of fixed effects.  }
  \item{beta}{parameter value for  fixed effects.  }
  \item{psi}{vector of length 3, with the non-zero elements of the Cholesky factor decomposition of the positive-definite \eqn{2 \times 2}{2 x 2} variance matrix of  random effects. }
  \item{X}{ a matrix of explanatory variables, of order \eqn{n \times p}{n x p}. }
  \item{Z}{ a matrix of order \eqn{n \times 2}{n x 2} with the variables associated to a random coefficients. Typically, the first column will be a vector of ones, but actually this need not be the case. }
  \item{y}{ a matrix of order  \eqn{n \times 2}{n x 2}. The first column contains the response variable, and the second column the binomial denominators. }
 \item{ni}{ cluster sizes, a vector of length equal to the nymber of clusters \eqn{m}{m}.  }
  \item{mat}{ object containing the information used for numerical integration. For Gauss-Legendre, is an object returned by calling the function \code{gauss.quad} of library \code{statmod}. For Monte Carlo integration is a 3-dimensional array with dimension 
\eqn{Q \times m \times 2}{Q x m x 2} of uniform randon draws. A suggested choice is to use Quasi-Monte Carlo draws.}
  \item{type}{method used for Monte Carlo integration, either \code{"gl"} for Gauss-Legendre integration or any other value for Monte Carlo integration.  The default is \code{"gl"}. }
\item{beta.init}{starting value for fixed effects to be used for  maximization of \code{lik.beta.logit2}.}
\item{mle}{numerical value of maximun likelihood estimate of fixed effects and \eqn{\psi}{psi}.}
\item{method}{method for \code{optim} call for  maximization of \code{lik.beta.logit2}. Default is \code{"BFGS"}.}
}
\details{
 \code{lik.logit2}  returns the log-likelihood  for the full parameter, while \code{lik.beta.logit2} and \code{grad.beta.logit2} return the log-likelihood and the gradient 
 when \eqn{\psi}{psi} is taken as known. \code{prof.logit2} returns the profile log-likelihood,
whereas \code{reml.logit2}  returns the modified profile log-likelihoods for  \eqn{\psi}{psi}.
}
\value{
  For  \code{lik.logit2},  \code{lik.beta.logit2},   \code{prof.logit2} and \code{reml.logit2}  a log-likelihood value. For   \code{grad.beta.logit2}
a gradient value for  fixed effects.
}
\references{ Bellio, R. and Brazzale, A. R. (2011). "Restricted Likelihood Inference for Generalized Linear Mixed Models". Statistics and Computing, 21, 173-183.  }
\author{Ruggero Bellio <ruggero.bellio@uniud.it>}
\examples{
## Multicenter data 
data(multicenter)
## Create some of the required data objects
X <- model.matrix(~I(trt==1), data=multicenter)
y <- cbind(multicenter$y, multicenter$den)
N <- tapply(rep(1,nrow(X)), multicenter$ID, sum)
## Laplace-based MLE  for finding a  preliminary estimate
obj.lap <- glmer(cbind(y,den-y) ~ I(trt==1) + (I(trt==1)|ID), family=binomial, 
                 data=multicenter)
init<- c(fixef(obj.lap), as.vector(chol(VarCorr(obj.lap)$ID))[-2] )
## Maximum likelihood estimation based on Gauss-Legendre integration
## 50 points for each dimension 
mat.gl <-  gauss.quad(50,"legendre")
## Note that here Z=X 
mle.psi <- optim(init[3:5], prof.logit2, X=X, Z=X, y=y, ni=N, mat=mat.gl, type="gl",
                 beta.init=fixef(obj.lap), control=list(fnscale=-1))$par
mle.beta <- optim(init[1:ncol(X)], lik.beta.logit2, grad.beta.logit2, psi=mle.psi,
                  X=X, y=y, ni=N, Z=X, mat=mat.gl, type="gl", method="BFGS", 
                  control=list(fnscale=-1))$par
mle <- c(mle.beta, mle.psi)
## REML-type estimate
mpl.psi <- optim(mle.psi, reml.logit2, X=X, Z=X, y=y, ni=N, mle=mle, mat=mat.gl, type="gl", 
                 beta.init=mle.beta, control=list(fnscale=-1))$par
## Compare the estimated variance matrix of random effects
V.mle <- crossprod(matrix(c(mle.psi[1], 0, mle.psi[2:3]), 2, 2))
V.reml <- crossprod(matrix(c(mpl.psi[1], 0, mpl.psi[2:3]),2, 2))
## The function QUnif of package "sfsmisc" provides Halton sequences for 
## Quasi-Monte Carlo integration
## First build the 3-dimensional array of uniform pseudo-draws
Q<-2000
mat2<-  QUnif(Q, p=2) 
mat.halton2 <- array(NA, dim=c(Q,length(N),2))
for(i in 1:length(N)) mat.halton2[,i,] <- mat2
## Find the MLE by profiling
mle.psi.halton <- optim(init[3:5], prof.logit2, X=X, Z=X, y=y, ni=N, mat=mat.halton2, 
                        type="qmc", beta.init=fixef(obj.lap), control=list(fnscale=-1))$par
mle.beta.halton <- optim(init[1:ncol(X)], lik.beta.logit2, grad.beta.logit2, 
                         psi=mle.psi.halton, X=X, y=y, ni=N, Z=X, mat=mat.halton2, 
                         type="qmc", method="BFGS", control=list(fnscale=-1))$par
mle.halton <- c(mle.beta.halton, mle.psi.halton)
## REML-type estimate
mpl.psi.halton <- optim(mle.psi.halton, reml.logit2, X=X, Z=X, y=y, ni=N, mle=mle.halton, 
                        mat=mat.halton2, type="qmc", beta.init=mle.beta.halton, 
                        control=list(fnscale=-1))$par
## Compare the estimated variance matrix of random effects
V.mle.halton <- crossprod(matrix(c(mle.psi.halton[1], 0, mle.psi.halton[2:3]), 2, 2))
V.reml.halton <- crossprod(matrix(c(mpl.psi.halton[1], 0, mpl.psi.halton[2:3]), 2, 2))
}
\keyword{regression}
