\name{poisnb}
\alias{lik.pois}
\alias{lik.beta.pois}
\alias{grad.beta.pois}
\alias{prof.pois}
\alias{reml.pois}
\alias{lik.nb}
\alias{lik.beta.nb}
\alias{grad.beta.nb}
\alias{prof.nb}
\alias{reml.nb}
\title{Poisson and negative binomial regression with random intercepts.}
\description{
Functions for log-likelihood computations.
 }
\usage{
lik.pois(theta, X, y, ni, offset, mat, type = "gl")
lik.beta.pois(beta, psi, X, y, ni, offset, mat, type)
grad.beta.pois(beta, psi, X, y, ni, offset, mat, type)
prof.pois(psi, X, y, ni, offset, mat, beta.init, type = "gl", method="BFGS")
reml.nb(psi, X, y, ni, offset, mat, beta.init, mle, type = "gl",method="BFGS")
lik.nb(theta, X, y, ni, offset, mat, type = "gl")
lik.beta.nb(beta, psi, X, y, ni, offset, mat, type)
grad.beta.nb(beta, psi, X, y, ni, offset, mat, type)
prof.nb(psi, X, y, ni, offset, mat, beta.init, type = "gl", method="BFGS")
reml.nb(psi, X, y, ni, offset, mat, beta.init, mle, type = "gl",method="BFGS")
}
\arguments{
  \item{theta}{ parameter value, formed by fixed effects and  \eqn{\psi}{psi} (in that order). For Poisson regression, a vector of dimension \eqn{p+1}{p+1}, where \eqn{p}{p} is the number of fixed effects. For negative binomial regression a vector of dimension \eqn{p+2}{p+2}.}
 \item{beta}{parameter value for  fixed effects.  }
 \item{psi}{for Poisson regression, random effects standard deviation. For negative binomial regression, a vector of length  2, formed by  random effects standard deviation and overdispersion parameter. The parameterization employed for overdispersion is the same as in \code{glm.nb} in \code{MASS} package, though the overdispersion parameter should be taken in \code{log} form. }
  \item{X}{ a matrix of explanatory variables, of order \eqn{n \times p}{n x p}. }
  \item{y}{ a vector of length  \eqn{n}{n}. The count-data response variable.  } 
  \item{ni}{ cluster sizes, a vector of length equal to the number of clusters \eqn{m}{m}.  }
  \item{offset}{ a vector of length  \eqn{n}{n} containing offset values. Should be set to \code{rep(0,length(y))} in case there is no offset. }
  \item{mat}{ object containing the information used for numerical integration. For Gauss-Legendre, is an object returned by calling the function \code{gauss.quad} of library \code{statmod}. For Monte Carlo integration is a matrix of order \eqn{m \times Q}{m x Q} of uniform randon draws. A suggested choice is to use Quasi-Monte Carlo draws.}
  \item{type}{method used for Monte Carlo integration, either \code{"gl"} for Gauss-Legendre integration or any other value for Monte Carlo integration.  The default is \code{"gl"}. }
  \item{beta.init}{starting value for fixed effects to be used for  maximization of \code{lik.beta.pois} and \code{lik.beta.nb}.}
  \item{mle}{numerical value of maximun likelihood estimate of fixed effects and \eqn{\psi}{psi}.}
  \item{method}{method for \code{optim} call for  maximization of \code{lik.beta.pois} and \code{lik.beta.nb}. Default is \code{"BFGS"}.}
 }
\details{
\code{lik.pois} and \code{lik.nb} return the log-likelihood  for the full parameter, while \code{lik.beta.pois},
\code{grad.beta.pois}, \code{lik.nb} and \code{grad.beta.nb} return the log-likelihood and the gradient 
 when \eqn{\psi}{psi} is taken as known. \code{prof.pois} and \code{prof.nb} return the profile log-likelihood,
whereas \code{reml.pois} and \code{reml.nb} return the modified profile log-likelihoods for  \eqn{\psi}{psi}.
}
\value{
  For  \code{lik.pois}, \code{lik.nb},  \code{lik.beta.pois}, \code{lik.beta.nb},  \code{prof.pois},	\code{prof.nb}, \code{reml.logit1} and \code{reml.nb} a log-likelihood value. For  \code{grad.beta.pois} and 
\code{grad.beta.nb}
a gradient value for  fixed effects.
}
\references{ Bellio, R. and Brazzale, A. R. (2011). "Restricted Likelihood Inference for Generalized Linear Mixed Models". Statistics and Computing, 21, 173-183. }
\author{Ruggero Bellio <ruggero.bellio@uniud.it>}
\examples{
## Headache data
data(headache)
## First Poisson regression
## Create some of the required data objects  
X <- model.matrix(~ trt + factor(per) + offset(log(days)), data=headache)
y <- headache$y
N <- tapply(rep(1,nrow(X)), headache$ID, sum)
N <- N[unique(headache$ID)]
## Laplace-based MLE  for finding a  preliminary estimate
obj.lap <- glmer(y ~ offset(log(days)) + trt + factor(per) + (1|ID), family=poisson, 
                 data=headache)
## Maximum likelihood estimation based on Gauss-Legendre integration
mat.gl <-  gauss.quad(50,"legendre")
## Find the MLE by profiling
mle.psi <- optimise(prof.pois, c(0.0001,10), X=X, y=y, ni=N, offset=log(headache$days),
                    mat=mat.gl, type="gl", beta.init=fixef(obj.lap), maximum=TRUE,
                    tol=10^-8)$max
mle.beta <- optim(fixef(obj.lap), lik.beta.pois, grad.beta.pois,psi=mle.psi,X=X,y=y,
                  ni=N, mat=mat.gl, type="gl", offset=log(headache$days), method="BFGS",
                  control=list(fnscale=-1))$par
mle.pois<-c(mle.beta,mle.psi)
## REML-type estimate
mpl.psi<- optimise(reml.pois, c(0.0001,10), X=X, y=y, ni=N, offset=log(headache$days),
                   mat=mat.gl, type="gl", beta.init=mle.beta, mle=mle.pois, maximum=TRUE, 
                   tol=10^-8)$max 
## Negative binomial regression; use glm.nb of MASS for preliminary estimation of theta
obj.nb <- glm.nb(y ~ trt + factor(per) + offset(log(days)), headache)  
init <- c(fixef(obj.lap), sqrt((VarCorr(obj.lap)$ID)[1]), log(obj.nb$theta))
## Find the MLE by profiling
mle.psi <- optim(init[ncol(X)+1:2], prof.nb, X=X, y=y, ni=N, offset=log(headache$days), 
                 mat=mat.gl, type="gl", beta.init=fixef(obj.lap), 
                 control=list(fnscale=-1))$par
mle.beta <- optim(init[1:ncol(X)], lik.beta.nb, grad.beta.nb, psi=mle.psi, X=X, y=y, 
                  ni=N, mat=mat.gl, type="gl", offset=log(headache$days), method="BFGS", 
                  control=list(fnscale=-1))$par
mle.nb <- c(mle.beta, mle.psi)
## REML-type estimate
mpl.psi<- optim(mle.psi, reml.nb, X=X, y=y, ni=N, offset=log(headache$days), mat=mat.gl, 
                type="gl", beta.init=mle.beta, mle=mle.nb, control=list(fnscale=-1))
}
\keyword{regression}

