\name{twopart}
\alias{lik.tp}
\alias{lik.beta.tp}
\alias{grad.beta.tp}
\alias{prof.tp}
\alias{reml.tp}
\title{Two-part models with correlated random effects.}
\description{
Functions for log-likelihood computations.
}
\usage{
lik.tp(theta, X, Xs, y, ni, mat, type = "gl")
lik.beta.tp(beta, psi, X, Xs, y, ni,  mat, type)
grad.beta.tp(beta, psi, X, Xs, y, ni,  mat, type)
prof.tp(psi, X, Xs, y, ni,  mat, beta.init, type = "gl", method="BFGS")
reml.tp(psi, X, Xs, y, ni, mat, beta.init, mle, type = "gl", method="BFGS")
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{theta}{parameter value, formed by fixed effects and random effects parameters (in that order), corresponding to concatenating \code{beta} and \code{psi} together.  }
 \item{beta}{parameter value for  fixed effects, for the logistic and linear part (in that order). }
  \item{psi}{vector of length 4,  with the non-zero elements of the Cholesky factor decomposition of the positive-definite \eqn{2 \times 2}{2 x 2} variance matrix of  random effects plus the residual standard deviation of the linear part.}
 \item{X}{ a matrix of explanatory variables for the logistic part, of order \eqn{n \times p_1}{n x p1}. }
  \item{Xs}{ a matrix of explanatory variables for the linear part, of order \eqn{n \times p_2}{n x p2}. }
  \item{y}{  a matrix of order  \eqn{n \times 2}{n x 2}. The first column contains the response variable for the logistic part, and the second column the response variable for the linear part. Missing values are not allowed, even in \code{y[,2]}. }
  \item{ni}{ cluster sizes, a vector of length equal to the nymber of clusters \eqn{m}{m}.  }
  \item{mat}{ object containing the information used for numerical integration. For Gauss-Legendre, is an object returned by calling the function \code{gauss.quad} of library \code{statmod}. }
  \item{type}{method used for Monte Carlo integration, either \code{"gl"} for Gauss-Legendre integration or any other value for Monte Carlo integration.  Only Gauss-Legendre integration available at the moment. }
  \item{beta.init}{starting value for fixed effects to be used for  maximization of \code{lik.beta.tp}.}
  \item{mle}{numerical value of maximun likelihood estimate of fixed effects and \eqn{\psi}{psi}.}
  \item{method}{method for \code{optim} call for  maximization of \code{lik.beta.tp}. Default is \code{"BFGS"}.}
}
\details{
   \code{lik.tp}  returns the log-likelihood  for the full parameter, while \code{lik.beta.tp} and \code{grad.beta.tp} return the log-likelihood and the gradient 
 when \eqn{\psi}{psi} is taken as known. \code{prof.tp} returns the profile log-likelihood,
whereas \code{reml.tp}  returns the modified profile log-likelihoods for  \eqn{\psi}{psi}.
}
\value{
   For  \code{lik.tp},  \code{lik.beta.tp},   \code{prof.tp} and \code{reml.tp}  a log-likelihood value. For   \code{grad.beta.tp}
a gradient value for  fixed effects.
}
\references{ Bellio, R. and Brazzale, A. R. (2011). "Restricted Likelihood Inference for Generalized Linear Mixed Models". Statistics and Computing, 21, 173-183.  }
\author{Ruggero Bellio <ruggero.bellio@uniud.it>}
\examples{
## Simulated two-part pdata 
data(tpdata)
## Create some of the required data objects
X <- model.matrix( ~ x1 + factor(x2), data=tpdata)
y <- cbind(tpdata$u, tpdata$v)
N <- tapply(rep(1,nrow(X)), tpdata$cluster, sum)
## Preliminary estimation of one-part models
obj1 <- glmer(u ~ x1 + factor(x2) + (1|cluster), family=binomial, data=tpdata)
obj2 <- lmer(v ~ x1 + factor(x2) + (1|cluster), data=tpdata, subset=(u==1))
## Starting point assumes uncorrelated random effects
V <- matrix(c(sqrt((VarCorr(obj1)$cluster)[1]), 0, 0,
             sqrt((VarCorr(obj2)$cluster)[1])), 2, 2)
init <- c(fixef(obj1), fixef(obj2), as.vector(chol(V))[-2], attr(VarCorr(obj2),"sc"))
## Maximum likelihood estimation based on Gauss-Legendre integration
mat.gl <-  gauss.quad(50,"legendre")
## Note that here Xs=X
mle.psi <- optim(init[-(1:8)], prof.tp, X=X, Xs=X, y=y, ni=N, mat=mat.gl, type="gl", 
                beta.init=init[1:8], control=list(fnscale=-1))$par
mle.obj <- optim(init[1:8], lik.beta.tp, grad.beta.tp, psi=mle.psi, X=X, y=y, ni=N,
                  Xs=X, mat=mat.gl, type="gl", method="BFGS", 
                  hessian=TRUE, control=list(fnscale=-1))
mle.beta <- mle.obj$par
mle <- c(mle.beta, mle.psi)
## REML-type estimate
mpl.psi<- optim(mle.psi, reml.tp, X=X, Xs=X, y=y, ni=N, mle=mle, mat=mat.gl, 
                type="gl", beta.init=mle.beta, control=list(fnscale=-1))$par
## Compare the estimated variance matrix of random effects
V.mle <- crossprod(matrix(c(mle.psi[1], 0, mle.psi[2:3]), 2, 2))
V.mpl <- crossprod(matrix(c(mpl.psi[1], 0, mpl.psi[2:3]), 2, 2))
## REML-type  estimate of fixed effects
mpl.obj<- optim(mle.beta, lik.beta.tp, grad.beta.tp, psi=mpl.psi, X=X, y=y, ni=N,
                  Xs=X, mat=mat.gl, type="gl", method="BFGS", 
                  hessian=TRUE, control=list(fnscale=-1))
mpl.beta <- mpl.obj$par
## Compare estimates on fixed effects
cbind(mle.beta, sqrt(diag(solve(-mle.obj$hessian))),
      mpl.beta, sqrt(diag(solve(-mpl.obj$hessian))) )
}
\keyword{regression}

